package com.autentia.workflow;

import java.util.List;

import javax.annotation.Resource;

import org.springframework.stereotype.Service;

import com.autentia.workflow.dao.Dao;
import com.autentia.workflow.errors.MyAppException;
import com.autentia.workflow.utils.WorkflowUtils;
import com.opensymphony.workflow.WorkflowException;

@Service
public class CommissioningMgr {

	@Resource
	private Dao dao;

	@Resource
	private WorkflowUtils workflowUtils;

	public Commissioning newCommissioning() {
		return new Commissioning();
	}

	public void persist(final Commissioning commissioning) throws MyAppException {
		// si es nuevo
		if (commissioning.getId() == null) {
			try {
				commissioning.setWorkflowId(this.workflowUtils.newWorkflow());
				commissioning.setState(1);
				this.dao.persist(commissioning);
			} catch (final WorkflowException e) {
				throw new MyAppException(e);
			}
		} else {
			this.dao.persist(commissioning);
		}

	}

	public List<Commissioning> getCommissionings() {
		final List<Commissioning> list = this.dao.find(Commissioning.class);
		return list;
	}

	public int[] getAvalaibleActions(final Commissioning commissioning) {
		final Long wfId = commissioning.getWorkflowId();
		return this.workflowUtils.getAvalaibleActions(wfId);

	}

	public void executeAction(final Commissioning commissioning, final int actionId) throws MyAppException {
		try {
			final Long wfId = commissioning.getWorkflowId();
			this.workflowUtils.executeAction(wfId, actionId);
			this.dao.refresh(commissioning);
		} catch (final WorkflowException e) {
			throw new MyAppException(e);
		}
	}

	public Commissioning findById(final Integer id) {
		final Commissioning commissioning = this.dao.get(Commissioning.class, id);
		return commissioning;
	}

	public Commissioning findByWorkflowId(final long id) throws MyAppException {
		final Object[] params = { id };
		final List<Commissioning> list = this.dao.findForWorkflowFuntion(Commissioning.findByWorkflowId, params);
		// como mximo slo debera haber uno
		if (list.size() > 1) {
			throw new MyAppException("solo debera haber un pedido apuntando a este workflow");
		} else if (list.size() == 1) {
			return list.get(0);
		} else {
			return null;
		}
	}
}
