package com.autentia.workflow.dao;

import java.io.Serializable;
import java.util.List;

import org.hibernate.SessionFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;
import org.springframework.stereotype.Repository;
import org.springframework.transaction.annotation.Transactional;

@Repository
public class SpringHibernateDao extends HibernateDaoSupport implements Dao {

	@Autowired
	public SpringHibernateDao(final SessionFactory sessionFactory) {
		super.setSessionFactory(sessionFactory);
	}

	@Transactional
	public void persist(final Object entity) {
		this.getHibernateTemplate().saveOrUpdate(entity);
	}

	@Transactional
	public void persist(final Object[] entities) {
		for (final Object element : entities) {
			this.persist(element);
		}
	}

	@Transactional(readOnly = true)
	public <T> List<T> find(final Class<T> entityClass) {
		final List<T> entities = this.getHibernateTemplate().loadAll(entityClass);
		return entities;
	}

	@Transactional(readOnly = true)
	public <T> T get(final Class<T> entityClass, final Serializable id) {
		final T entity = (T)this.getHibernateTemplate().get(entityClass, id);
		return entity;
	}

	@Transactional(readOnly = true)
	public <T> List<T> find(final String hql) {
		final List<T> entities = this.getHibernateTemplate().find(hql);
		return entities;
	}

	@Transactional
	public <T> List<T> findForWorkflowFuntion(final String queryName, final Object[] values) {
		final List<T> entities = this.getHibernateTemplate().findByNamedQuery(queryName, values);

		return entities;
	}

	@Transactional
	public void refresh(final Object entity) {
		this.getHibernateTemplate().refresh(entity);
	}

}